@@ -12,8 +12,8 @@ from distutils.spawn import find_executable
 matam_16s_usage = '''
 =================================== matam_16s example commands ===================================
 
-MarkerMAG matam_16s -p Test -r1 R1.fasta -r2 R2.fasta -t 12 -d path/to/SILVA_138_SSURef_NR99
-MarkerMAG matam_16s -p Test -r16s 16S_reads.fasta -t 12 -d path/to/SILVA_138_SSURef_NR99
+MarkerMAG matam_16s -p Test -r1 R1.fastq -r2 R2.fastq -t 12 -d path/to/SILVA_138_SSURef_NR99
+MarkerMAG matam_16s -p Test -r16s 16S_reads.fastq -t 12 -d path/to/SILVA_138_SSURef_NR99
 
 # please refer to here for the preparation of input files
 https://github.com/songweizhi/MarkerMAG/blob/master/doc/README_matam_16s.md
@@ -32,18 +32,6 @@ def report_and_log(message_for_report, log_file, keep_quiet):
         print('%s %s' % ((datetime.now().strftime(time_format)), message_for_report))
 
 
-def force_create_folder(folder_to_create):
-    if os.path.isdir(folder_to_create):
-        shutil.rmtree(folder_to_create, ignore_errors=True)
-        if os.path.isdir(folder_to_create):
-            shutil.rmtree(folder_to_create, ignore_errors=True)
-            if os.path.isdir(folder_to_create):
-                shutil.rmtree(folder_to_create, ignore_errors=True)
-                if os.path.isdir(folder_to_create):
-                    shutil.rmtree(folder_to_create, ignore_errors=True)
-    os.mkdir(folder_to_create)
-
-
 def sep_path_basename_ext(file_in):
 
     # separate path and file name
@@ -290,9 +278,9 @@ def matam_16s(args):
 
     input_reads_fmt = ''
     if extract_16s_reads is True:
-        input_reads_fmt = os.path.splitext(input_16S_reads)
+        input_reads_fmt = os.path.splitext(reads_file_r1)[1]
     else:
-        input_reads_fmt = os.path.splitext(reads_file_r1)
+        input_reads_fmt = os.path.splitext(input_16S_reads)[1]
 
 
     ####################################################################################################################
@@ -307,11 +295,15 @@ def matam_16s(args):
     uclust_output_fasta                     = '%s/%s_assembled_16S_uclust_%s.fasta'     % (matam16s_wd, output_prefix, uclust_iden_cutoff)
 
     # create folder
-    if (os.path.isdir(matam16s_wd) is True) and (force_overwrite is False):
-        print('Output folder detected, program exited: %s' % matam16s_wd)
-        exit()
-    else:
+    if os.path.isdir(matam16s_wd) is False:
         os.mkdir(matam16s_wd)
+    else:
+        if force_overwrite is False:
+            print('Output folder detected, program exited: %s' % matam16s_wd)
+            exit()
+        else:
+            os.system('rm -r %s' % matam16s_wd)
+            os.mkdir(matam16s_wd)
 
     if extract_16s_reads is True:
 
